# Tahoe Figures Plugins
Backends and customizations for Figures in Tahoe.


# Usage

 - Install this package `pip install tahoe-figures-plugins`
 - In the `server-vars.yml` configure `FIGURES.REQUESTED_SITE_BACKEND` to be `tahoe_figures_plugins.sites:get_current_site_or_by_uuid`


# Change Log
 - `v0.1.0` First release
